@@ -31,6 +31,7 @@ HAS_UPDATED_LINENOS = sys.version_info[0] >= 3 and sys.version_info[1] >= 8
 class CallDefNode(object):
     """
     Attributes:
+        callname (str): the name of the "calldef"
         doclineno (int): the line number (1 based) the docstring begins on
         doclineno_end (int): the line number (1 based) the docstring ends on
     """
@@ -44,10 +45,10 @@ class CallDefNode(object):
         self.lineno_end = None
         self.args = args
 
-    # def __str__(self):
-    #     return '{}[{}:{}][{}]'.format(
-    #         self.callname, self.lineno, self.lineno_end,
-    #         self.doclineno)
+    def __str__(self):
+        return '{}[{}:{}][{}]'.format(
+            self.callname, self.lineno, self.lineno_end,
+            self.doclineno)
 
 
 class TopLevelVisitor(ast.NodeVisitor):
@@ -65,23 +66,34 @@ class TopLevelVisitor(ast.NodeVisitor):
         >>> from xdoctest.static_analysis import *  # NOQA
         >>> from xdoctest import utils
         >>> source = utils.codeblock(
-        ...    '''
-        ...    def foo():
-        ...        \"\"\" my docstring \"\"\"
-        ...        def subfunc():
-        ...            pass
-        ...    def bar():
-        ...        pass
-        ...    class Spam(object):
-        ...        def eggs(self):
-        ...            pass
-        ...        @staticmethod
-        ...        def hams():
-        ...            pass
-        ...    ''')
+                '''
+                def foo():
+                    \"\"\" my docstring \"\"\"
+                    def subfunc():
+                        pass
+                def bar():
+                    pass
+                class Spam(object):
+                    def eggs(self):
+                        pass
+                    @staticmethod
+                    def hams():
+                        pass
+                    @property
+                    def jams(self):
+                        return 3
+                    @jams.setter
+                    def jams2(self, x):
+                        print('ignoring')
+                    @jams.deleter
+                    def jams(self, x):
+                        print('ignoring')
+                ''')
         >>> self = TopLevelVisitor.parse(source)
         >>> callnames = set(self.calldefs.keys())
-        >>> assert callnames == {'foo', 'bar', 'Spam', 'Spam.eggs', 'Spam.hams'}
+        >>> assert callnames == {
+        >>>     'foo', 'bar', 'Spam', 'Spam.eggs', 'Spam.hams',
+        >>>     'Spam.jams'}
         >>> assert self.calldefs['foo'].docstr.strip() == 'my docstring'
         >>> assert 'subfunc' not in self.calldefs
     """
@@ -142,6 +154,23 @@ class TopLevelVisitor(ast.NodeVisitor):
         else:
             callname = self._current_classname + '.' + node.name
 
+        if node.decorator_list:
+            for decor in node.decorator_list:
+                if isinstance(decor, ast.Name):
+                    if decor.id == 'property':
+                        # likely a getter property
+                        # should we distinguish getters?
+                        # callname = callname + '.fget'
+                        pass
+                if isinstance(decor, ast.Attribute):
+                    # Don't add setters / deleters to the callnames
+                    if decor.attr == 'deleter':
+                        # callname = callname + '.fdel'
+                        return
+                    if decor.attr == 'setter':
+                        # callname = callname + '.fset'
+                        return
+
         lineno = self._workaround_func_lineno(node)
         docstr, doclineno, doclineno_end = self._get_docstring(node)
         calldef = CallDefNode(callname, lineno, docstr, doclineno,
@@ -605,7 +634,7 @@ class TopLevelVisitor(ast.NodeVisitor):
         return lineno
 
 
-def parse_calldefs(source=None, fpath=None):
+def parse_static_calldefs(source=None, fpath=None):
     """
     Statically finds top-level callable functions and methods in python source
 
@@ -614,13 +643,15 @@ def parse_calldefs(source=None, fpath=None):
         fpath (str): filepath to read if source is not specified
 
     Returns:
-        dict(str, CallDefNode): map of callnames to tuples with def info
+        Dict[str, CallDefNode]:
+            maping from callnames to CallDefNodes, which contain
+               info about the item with the doctest.
 
     Example:
         >>> from xdoctest import static_analysis
         >>> fpath = static_analysis.__file__.replace('.pyc', '.py')
-        >>> calldefs = parse_calldefs(fpath=fpath)
-        >>> assert 'parse_calldefs' in calldefs
+        >>> calldefs = parse_static_calldefs(fpath=fpath)
+        >>> assert 'parse_static_calldefs' in calldefs
     """
     if six.PY2:
         fpath = fpath.replace('.pyc', '.py')
@@ -647,6 +678,14 @@ def parse_calldefs(source=None, fpath=None):
         raise
 
 
+def parse_calldefs(source=None, fpath=None):
+    import warnings
+    warnings.warn((
+        'parse_calldefs is deprecated '
+        'use parse_static_calldefs instead'), DeprecationWarning)
+    return parse_static_calldefs(source=source, fpath=fpath)
+
+
 def _parse_static_node_value(node):
     """
     Extract a constant value from a node if possible
